@@ -238,12 +238,12 @@ class Shell(Command):
         """
 
         context = self.get_context()
-        
+
         if not no_bpython:
             # Try BPython
             try:
                 from bpython import embed
-                embed(banner=self.banner, locals_=self.get_context())
+                embed(banner=self.banner, locals_=context)
                 return
             except ImportError:
                 pass
@@ -251,12 +251,15 @@ class Shell(Command):
         if not no_ipython:
             # Try IPython
             try:
-                import IPython
                 try:
-                    sh = IPython.Shell.IPShellEmbed(banner=self.banner)
+                    # 0.10.x
+                    from IPython.Shell import IPShellEmbed
+                    ipshell = IPShellEmbed(banner=self.banner)
+                    ipshell(global_ns=dict(), local_ns=context)
                 except AttributeError:
-                    sh = IPython.frontend.terminal.embed.InteractiveShellEmbed(banner1=self.banner)
-                sh(global_ns=dict(), local_ns=context)
+                    # 0.12+
+                    from IPython import embed
+                    embed(banner1=self.banner, local_ns=context)
                 return
             except ImportError:
                 pass
